@@ -834,7 +834,7 @@ def performPush(url, token, start, number, branch, blame):
     if debug:
         if not os.path.exists('./testbrain-debug'):
             os.makedirs('./testbrain-debug')
-        current_time = datetime.datetime.now(datetime.timezone.utc).astimezone().strftime('%Y-%m-%dT%H:%M:%S%Z')
+        current_time = datetime.datetime.now(datetime.timezone.utc).astimezone().strftime('%Y-%m-%dT')
         with open(f'./testbrain-debug/{current_time}.json', 'w') as f:
             f.write(data)
     status_code, content = request(url, token, data, event='push')
